==> wizzi-web-0.6.8.tgz: package/readme.md <==
# wizzi-web - ver 0.6 - plugin package

A wizzi factory plugin for html css scss svg markdown and graphql artifact generations..

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented wizzi models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>html</td>
<td>Html wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>html/document</td>
</tr>
</table>

</tr>
<tr>
<td>css</td>
<td>Cascading style sheet wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>css/document</td>
</tr>
</table>

</tr>
<tr>
<td>scss</td>
<td>Sass cascading style sheet wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>scss/document</td>
</tr>
</table>

</tr>
<tr>
<td>svg</td>
<td>Scalable Vector Graphics wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>svg/document</td>
</tr>
</table>

</tr>
<tr>
<td>md</td>
<td>Markdown wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>md/document</td>
</tr>
</table>

</tr>
<tr>
<td>graphql</td>
<td>Graphql wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>site</td>
<td>Components of a website structure</td>
<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>vtt</td>
<td>Video Text Tracks specification</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>vtt/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi plugins are documented\b<a href="https://wizzifactory.github.io/docs/plugins.html">here</a>.</p>



<p>You can find a few samples in the /example folder, but you can find more in the\b<a href="https://github.com/wizzifactory/wizzi-demo">demo package</a>.</p>

## Source and generation
wizzi-web is generated using the wizzi factory ver 0.5

## The Wizzi Factory - ver 0.6

A set of tools for model driven development.


<p><a href="https://wizzifactory.github.io/">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the\b<a href="license.txt">license.txt\b</a><p>for details.</p></p>

==> wizzi-web-0.6.11.tgz: package/readme.md <==
# wizzi-web - ver 0.6 - plugin package

A wizzi factory plugin for html css scss svg markdown and graphql artifact generations..

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented wizzi models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>html</td>
<td>Html wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>html/document</td>
</tr>
</table>

</tr>
<tr>
<td>css</td>
<td>Cascading style sheet wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>css/document</td>
</tr>
</table>

</tr>
<tr>
<td>scss</td>
<td>Sass cascading style sheet wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>scss/document</td>
</tr>
</table>

</tr>
<tr>
<td>svg</td>
<td>Scalable Vector Graphics wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>svg/document</td>
</tr>
</table>

</tr>
<tr>
<td>md</td>
<td>Markdown wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>md/document</td>
</tr>
</table>

</tr>
<tr>
<td>graphql</td>
<td>Graphql wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>site</td>
<td>Components of a website structure</td>
<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>vtt</td>
<td>Video Text Tracks specification</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>vtt/document</td>
</tr>
</table>

</tr>
<tr>
<td>vue</td>
<td>Vue wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>vue/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi plugins are documented<a href="https://wizzifactory.github.io/docs/plugins.html">here</a>.</p>



<p>You can find a few samples in the /example folder, but you can find more in the<a href="https://github.com/wizzifactory/wizzi/packages/wizzi-demo">demo package</a>.</p>

## Source and generation
wizzi-web is generated using the wizzi factory ver 0.5

## The Wizzi Factory - ver 0.6

A set of tools for model driven development.


<p><a href="https://wizzifactory.github.io/">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the<a href="license.txt">license.txt</a><p>for details.</p></p>
